@@ -42,6 +42,36 @@ import re
 import MySQLdb
 import string
 import sys
+import subprocess
+
+#
+# Detect whether we are running Apache 2.2 or not so we set proper configuration
+# directives later on. We assume 2.2 until proven otherwise. We also assume
+# standard Debian or Redhat server locations. If running a custom installation
+# this will likely fall back to assuming 2.2.
+#
+# @TODO: Add commandline or environment variable overrides to the autodetection
+#
+
+apache_2_2 = True
+apache_bin = False
+
+if os.path.exists('/usr/sbin/apache2'):
+     apache_bin = '/usr/sbin/apache2'
+
+if os.path.exists('/usr/sbin/httpd'):
+     apache_bin = '/usr/sbin/httpd'
+
+if apache_bin:
+  proc = subprocess.Popen([apache_bin, "-v"], stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
+  out, err = proc.communicate()
+
+  needle = r'(?m)^.*Apache/(\d+)\.(\d+)\.(\d+).*$'
+
+  m = re.match(needle, out)
+
+  if m and m.group(1) >= 2 and m.group(2) > 2:
+    apache_2_2 = False
 
 db = False
 dbcursor = False
@@ -165,12 +195,15 @@ for dir in dirlist:
     url = string.replace(svnurl, "@PROJECT@", id)
 
     print "<Location " + url + ">"
+    print "\tRemoveEncoding .gz"
+    print "\tRemoveEncoding .Z"
     print "\tDAV svn"
     print "\tSVNPath " + svnroot + "/" + id
     print "\tAuthType Basic"
     print "\tAuthBasicProvider ldap"
     print "\tAuthName \"" + name.replace('"',r'\"') + " Subversion Repository\""
-    print "\tAuthzLDAPAuthoritative on"
+    if apache_2_2:
+      print "\tAuthzLDAPAuthoritative on"
     if (ldapbinduser != ""):
       print "\tAuthLDAPBindDN \"" + ldapbinduser + "\""
       print "\tAuthLDAPBindPassword \"" + ldapbindpass + "\""
